/*
 * #%L
 * *********************************************************************************************************************
 * 
 * SolidBlue - open source safe data
 * http://solidblue.tidalwave.it - hg clone https://bitbucket.org/tidalwave/solidblue-src
 * %%
 * Copyright (C) 2011 - 2013 Tidalwave s.a.s. (http://tidalwave.it)
 * %%
 * *********************************************************************************************************************
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 * 
 * *********************************************************************************************************************
 * 
 * $Id$
 * 
 * *********************************************************************************************************************
 * #L%
 */
package it.tidalwave.actor.impl.io.fileload;

import it.tidalwave.actor.impl.io.fileload.FileLoaderActor;
import java.util.Random;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import org.openide.filesystems.FileUtil;
import it.tidalwave.actor.io.fileload.FileLoadRequest;
import lombok.Cleanup;
import lombok.extern.slf4j.Slf4j;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

/***********************************************************************************************************************
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
@Slf4j
public class FileLoaderActorTest
  {
    private final static double MEGA =  1024 * 1024;
    private final static int MIN_FILE_SIZE =  10 * 1000 * 1000;
    private final static int MAX_FILE_SIZE = 100 * 1000 * 1000;
    
    private FileLoaderActor fixture;
    
    private File testFileFolder;
    
    @BeforeClass
    private void createTestFiles() 
      throws IOException
      {
        log.info("Creating test files...");
        testFileFolder = new File("target/test-files");
        testFileFolder.mkdirs();
        final Random random = new Random(342345426536L);
        
        for (int f = 0; f < 20; f++)
          {
            final File file = new File(testFileFolder, "testfile" + f);
            log.info(">>>> creating {} ...", file.getAbsolutePath());
            int size = MIN_FILE_SIZE + random.nextInt(MAX_FILE_SIZE - MIN_FILE_SIZE);
            final byte[] buffer = new byte[size];
            random.nextBytes(buffer);
            final @Cleanup FileOutputStream fos = new FileOutputStream(file);
            fos.write(buffer);
            fos.close();
          }
      }
    
    @BeforeMethod
    public void setupFixture()
      {
        fixture = new FileLoaderActor();
      }
    
    @Test
    public void test()
      throws Exception
      { 
        final long startTime = System.currentTimeMillis();
        long size = 0;
        
        for (int f = 0; f < 20; f++)
          {
            final File file = new File(testFileFolder, "testfile" + f).getAbsoluteFile();
            final FileLoadRequest fdMessage = FileLoadRequest.forPath(file.toPath());
            fixture.onFileLoadRequest(fdMessage);
            size += file.length();
          }
        
        final long time = System.currentTimeMillis() - startTime;
        log.info("Read {} MB, speed {} MB/sec", (int)(size / MEGA), (int)(((size / MEGA) / (time / 1000.0))));
        // FIXME: assert contents
      }
  }
